==> haskell-storable-tuple-0.1-128-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-storable-tuple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 storable-tuple
version:              0.1
visibility:           public
id:                   storable-tuple-0.1-KreW7uH6iGV5VAjITA4rH8
key:                  storable-tuple-0.1-KreW7uH6iGV5VAjITA4rH8
license:              BSD-3-Clause
maintainer:           Henning Thielemann <storable@henning-thielemann.de>
author:               Henning Thielemann <storable@henning-thielemann.de>
stability:            Experimental
homepage:             http://code.haskell.org/~thielema/storable-tuple/
synopsis:             Storable instance for pairs and triples
description:
    Provides a Storable instance for pair and triple
    which should be binary compatible with C99 and C++.
    The only purpose of this package is to provide a standard location
    for this instance so that other packages needing this instance
    can play nicely together.
    Note however, that the original purpose of the @Storable@ class
    was the transfer of primitive types between Haskell and foreign code.
    This purpose was already extended by HSC,
    which creates @Storable@ instances for records from C header files.
    Nonetheless,
    @Storable@ instances for tuples were omitted from @base@ by intention.
    Instead of using the orphan instances from this package,
    you may instead use the custom class or the wrapper type
    from the module @Foreign.Storable.Record.Tuple@
    from the package @storable-record@.

category:             Data, Foreign
abi:                  1964503842a5803c1925a35ed0069f03
exposed:              True
exposed-modules:      Foreign.Storable.Tuple
import-dirs:          /usr/lib/ghc-9.4.8/site-local/storable-tuple-0.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/storable-tuple-0.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/storable-tuple-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-storable-tuple
hs-libraries:         HSstorable-tuple-0.1-KreW7uH6iGV5VAjITA4rH8
depends:
    base-4.17.2.1 base-orphans-0.9.3-HOf1XWEi853HRMMLyvb6TR
    storable-record-0.0.7-FKEdzqyxqRFB9sBddX0ONe
    utility-ht-0.0.17.2-FHHtVV4Pxq51WmhixLkkXy

haddock-interfaces:
    /usr/share/doc/haskell-storable-tuple/html/storable-tuple.haddock

haddock-html:         /usr/share/doc/haskell-storable-tuple/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-storable-tuple-0.1-133-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-storable-tuple.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 storable-tuple
version:              0.1
visibility:           public
id:                   storable-tuple-0.1-E7qglBDahTjClexpY91FJM
key:                  storable-tuple-0.1-E7qglBDahTjClexpY91FJM
license:              BSD-3-Clause
maintainer:           Henning Thielemann <storable@henning-thielemann.de>
author:               Henning Thielemann <storable@henning-thielemann.de>
stability:            Experimental
homepage:             http://code.haskell.org/~thielema/storable-tuple/
synopsis:             Storable instance for pairs and triples
description:
    Provides a Storable instance for pair and triple
    which should be binary compatible with C99 and C++.
    The only purpose of this package is to provide a standard location
    for this instance so that other packages needing this instance
    can play nicely together.
    Note however, that the original purpose of the @Storable@ class
    was the transfer of primitive types between Haskell and foreign code.
    This purpose was already extended by HSC,
    which creates @Storable@ instances for records from C header files.
    Nonetheless,
    @Storable@ instances for tuples were omitted from @base@ by intention.
    Instead of using the orphan instances from this package,
    you may instead use the custom class or the wrapper type
    from the module @Foreign.Storable.Record.Tuple@
    from the package @storable-record@.

category:             Data, Foreign
abi:                  c6092e6eaedac81cc76698029135894b
exposed:              True
exposed-modules:      Foreign.Storable.Tuple
import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/storable-tuple-0.1
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/storable-tuple-0.1
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/storable-tuple-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-storable-tuple
hs-libraries:         HSstorable-tuple-0.1-E7qglBDahTjClexpY91FJM
depends:
    base-4.18.3.0 base-orphans-0.9.3-Dv0WmqG0V8uKpsjClS5qBn
    storable-record-0.0.7-EBHfgjsEmOl8lKoZeeMXQV
    utility-ht-0.0.17.2-JNrBgDeBpaMAiyR6m5uAgt

haddock-interfaces:
    /usr/share/doc/haskell-storable-tuple/html/storable-tuple.haddock

haddock-html:         /usr/share/doc/haskell-storable-tuple/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
